@@ -539,6 +539,11 @@ our %strip = (
 	'^that apply to Network',
 	'^reserves the right',
 	'^this query, you',
+	'^Get a FREE domain name registration, transfer,',
+	'^- or just \$8.95 with monthly packages.',
+	'^http://www.networksolutions.com',
+	'^Visit AboutUs.org for more information',
+	'^<a href="http://www.aboutus.org/GREENSTYLE.COM">',
     ],
     'whois.directnic.com' => [
 	'^By submitting a WHOIS query',
@@ -629,6 +634,83 @@ our %strip = (
 	'^WHOIS services in order to protect',
 	'^integrity of the database.',
     ],
+    'whois.godaddy.com' => [
+	'^The data contained in GoDaddy.com,',
+	'^while believed by the company to be',
+	'^with no guarantee or warranties',
+	'^information is provided for the sole',
+	'^in obtaining information about domain',
+	'^Any use of this data for any other',
+	'^permission of GoDaddy.com, Inc.',
+	'^you agree to these terms of usage',
+	'^you agree not to use this data to',
+	'^dissemination or collection of this',
+	'^purpose, such as the transmission of',
+	'^and solicitations of any kind, including',
+	'^not to use this data to enable high volume,',
+	'^processes designed to collect or compile',
+	'^including mining this data for your own',
+	'^Please note: the registrant of the domain',
+	'^in the "registrant" field.  In most cases,',
+	'^is not the registrant of domain names listed',
+    ],
+    'whois.paycenter.com.cn' => [
+	'^The Data in Paycenter\'s WHOIS database is',
+	'^for information purposes, and to assist',
+	'^information about or related to a domain',
+	'^record\.',
+	'^Paycenter does not guarantee its accuracy.',
+	'^a WHOIS query, you agree that you will use',
+	'^for lawful purposes and that, under no',
+	'^you use this Data to:',
+	'^\(1\) allow, enable, or otherwise support',
+	'^of mass unsolicited, commercial',
+	'^via e-mail \(spam\); or',
+	'^\(2\) enable high volume, automated,',
+	'^apply to Paycenter or its systems.',
+	'^Paycenter reserves the right to modify',
+	'^By submitting this query, you agree to',
+    ],
+    'whois.enom.com' => [
+	'^=-=-=-=',
+	'^The data in this whois database is provided',
+	'^purposes only, that is, to assist you in',
+	'^related to a domain name registration record.',
+	'^available "as is," and do not guarantee its',
+	'^whois query, you agree that you will use this',
+	'^purposes and that, under no circumstances will',
+	'^enable high volume, automated, electronic',
+	'^this whois database system providing you this',
+	'^enable, or otherwise support the transmission',
+	'^commercial advertising or solicitations via',
+	'^mail, or by telephone. The compilation,',
+	'^other use of this data is expressly',
+	'^consent from us.',
+	'^We reserve the right to modify these',
+	'^this query, you agree to abide by these',
+	'^Version ',
+	'^<a href="',
+    ],
+    'whois.dotster.com' => [
+	'^The information in this whois database is',
+	'^purpose of assisting you in obtaining',
+	'^name registration records. This information',
+	'^and we do not guarantee its accuracy. By',
+	'^query, you agree that you will use this',
+	'^purposes and that, under no circumstances',
+	'^to: \(1\) enable high volume, automated,',
+	'^stress or load this whois database system',
+	'^information; or \(2\) allow,enable, or',
+	'^transmission of mass, unsolicited, commercial',
+	'^solicitations via facsimile, electronic mail,',
+	'^entitites other than your own existing customers.',
+	'^compilation, repackaging, dissemination or other',
+	'^is expressly prohibited without prior written',
+	'^company. We reserve the right to modify these',
+	'^time. By submitting an inquiry, you agree to',
+	'^and limitations of warranty.  Please limit',
+	'^minute and one connection.',
+    ],
 );
 
 our %exceed = (
